==> barsurf_0.1.0.tar.gz: barsurf/inst/doc/barsurf.R <==
### R code from vignette source 'barsurf.Rnw'

###################################################
### code chunk number 1: barsurf.Rnw:34-37
###################################################
options(continue=" ")
options(SweaveHooks=list(fig=function()
par(mar=c(4.1, 4.1, 2.6, 1.6), cex=0.7, cex.main=1)))


###################################################
### code chunk number 2: barsurf.Rnw:61-63
###################################################
library (barsurf)
library (colorspace)


###################################################
### code chunk number 3: barsurf.Rnw:72-73
###################################################
getOption("SweaveHooks")[["fig"]]()
plot3d.empty ()


###################################################
### code chunk number 4: barsurf.Rnw:85-89
###################################################
getOption("SweaveHooks")[["fig"]]()
x = y = 1:4
f = function (x, y) x ^ 2 + y ^ 2
z = outer (x, y, f)
plot3d.bar (,,z)


###################################################
### code chunk number 5: barsurf.Rnw:96-98
###################################################
getOption("SweaveHooks")[["fig"]]()
px = py = (0:4) ^ 2
plot3d.bar (px, py, z)


###################################################
### code chunk number 6: barsurf.Rnw:105-114
###################################################
col.map = c (
	1, 1, 2, 2,
	1, 1, 2, 2,
	3, 3, 4, 4,
	3, 3, 4, 4)
col1.palette = rainbow_hcl (4, start=140, end=275, l=75)
col2.palette = rainbow_hcl (4, start=140, end=275, l=80)
col1 = matrix (col1.palette [col.map], nrow=4, byrow=TRUE)
col2 = matrix (col2.palette [col.map], nrow=4, byrow=TRUE)


###################################################
### code chunk number 7: barsurf.Rnw:119-120
###################################################
getOption("SweaveHooks")[["fig"]]()
plot3d.bar (,,z, col1=col1, col2=col2)


###################################################
### code chunk number 8: barsurf.Rnw:127-128
###################################################
getOption("SweaveHooks")[["fig"]]()
plot3d.bar (px, py, z, col1=col1, col2=col2)


###################################################
### code chunk number 9: barsurf.Rnw:138-142
###################################################
getOption("SweaveHooks")[["fig"]]()
x = y = 1:4
f = function (x, y) x ^ 2 + y ^ 2
z = outer (x, y, f)
plot3d.surf (,,z)

==> barsurf_0.3.0.tar.gz: barsurf/inst/doc/barsurf.R <==
### R code from vignette source 'barsurf.Rnw'

###################################################
### code chunk number 1: barsurf.Rnw:34-37
###################################################
options(continue=" ")
options(SweaveHooks=list(fig=function()
par(mar=c(4.1, 4.1, 2.6, 1.6), cex=0.7, cex.main=1)))


###################################################
### code chunk number 2: barsurf.Rnw:75-77
###################################################
library (intoo)
library (barsurf)


###################################################
### code chunk number 3: barsurf.Rnw:86-87
###################################################
z1 = outer (1:10, 1:10, "+")


###################################################
### code chunk number 4: barsurf.Rnw:92-93
###################################################
getOption("SweaveHooks")[["fig"]]()
plot2d.cell (,,z1)


###################################################
### code chunk number 5: barsurf.Rnw:95-96
###################################################
getOption("SweaveHooks")[["fig"]]()
plot3d.bar (,,z1, zlim=c (0, 20) )


###################################################
### code chunk number 6: barsurf.Rnw:110-113
###################################################
x = y = 1:20
f = function (x, y) x ^ 2 + y ^ 2
z2 = outer (x, y, f)


###################################################
### code chunk number 7: barsurf.Rnw:118-119
###################################################
getOption("SweaveHooks")[["fig"]]()
plot2d.contour (,,z2)


###################################################
### code chunk number 8: barsurf.Rnw:121-122
###################################################
getOption("SweaveHooks")[["fig"]]()
plot3d.surface (,,z2)


###################################################
### code chunk number 9: barsurf.Rnw:135-138
###################################################
colv.1.rgb = c (1, 0, 0)
colv.1.hcl = rgb2hcl (colv.1.rgb)
round (colv.1.hcl, 2)


###################################################
### code chunk number 10: barsurf.Rnw:141-144
###################################################
colv.2.hcl = c (0, 50, 60)
colv.2.rgb = hcl2rgb (colv.2.hcl)
round (colv.2.rgb, 2)


###################################################
### code chunk number 11: barsurf.Rnw:161-163
###################################################
getOption("SweaveHooks")[["fig"]]()
use.theme ("blue")
test.theme ()


###################################################
### code chunk number 12: barsurf.Rnw:165-167
###################################################
getOption("SweaveHooks")[["fig"]]()
use.theme ("green")
test.theme ()


###################################################
### code chunk number 13: barsurf.Rnw:171-172
###################################################
use.theme ("blue")


###################################################
### code chunk number 14: barsurf.Rnw:176-178
###################################################
bso = getOption ("barsurf")
bso


###################################################
### code chunk number 15: barsurf.Rnw:181-183
###################################################
bso$plot2d.cell.colv.1 = c (90, 45, 65)
bso$plot2d.cell.colv.2 = c (360, 45, 65)


###################################################
### code chunk number 16: barsurf.Rnw:186-187
###################################################
options (barsurf=bso)


###################################################
### code chunk number 17: barsurf.Rnw:191-192
###################################################
getOption("SweaveHooks")[["fig"]]()
plot2d.cell (,,z1)


###################################################
### code chunk number 18: barsurf.Rnw:196-197
###################################################
use.theme ("blue")


###################################################
### code chunk number 19: barsurf.Rnw:208-211
###################################################
x = y = -9:10
f = function (x, y) 200 - (x ^ 2 + y ^ 2)
z3 = outer (x, y, f)


###################################################
### code chunk number 20: barsurf.Rnw:215-217
###################################################
z3 = lr2na (z3)
P.ht (z3)


###################################################
### code chunk number 21: barsurf.Rnw:222-223
###################################################
getOption("SweaveHooks")[["fig"]]()
plot2d.tricontour (,,z3)


###################################################
### code chunk number 22: barsurf.Rnw:225-226
###################################################
getOption("SweaveHooks")[["fig"]]()
plot3d.trisurface (,,z3)


###################################################
### code chunk number 23: barsurf.Rnw:238-239
###################################################
z4 = outer (1:8, 1:8, "+")


###################################################
### code chunk number 24: barsurf.Rnw:242-246
###################################################
sm.1 = P.smatrix (1, 2, 1, 2)
sm.2 = P.smatrix (1, 4, 1, 4)
sm.3 = P.smatrix (1, 6, 1, 6)
sm.4 = P.smatrix (1, 8, 1, 8)


###################################################
### code chunk number 25: barsurf.Rnw:249-250
###################################################
z4 = P.nmatrix (z4, list (sm.1, sm.2, sm.3, sm.4) )


###################################################
### code chunk number 26: barsurf.Rnw:253-254
###################################################
z4


###################################################
### code chunk number 27: barsurf.Rnw:258-259
###################################################
getOption("SweaveHooks")[["fig"]]()
plot2d.cell (,,z4)


###################################################
### code chunk number 28: barsurf.Rnw:262-263
###################################################
getOption("SweaveHooks")[["fig"]]()
plot3d.bar (,,z4, zlim=c (0, 16), colv.2=c (0, 0, 80), reverse=TRUE)
